@@ -10,11 +10,21 @@ def test_NBA():
     nba = NBA()
     assert len(nba.teams) == 30
 
+def test_NBA_standings():
+    nba = NBA()
+    assert len(nba.conference_standings('east')) == 15 and \
+        len(nba.conference_standings('west')) == 15
+
 
 def test_NHL():
     nhl = NHL()
     assert len(nhl.teams) == 32
 
+def test_NHL_standings():
+    nhl = NHL()
+    assert len(nhl.conference_standings('east')) == 16 and \
+        len(nhl.conference_standings('west')) == 16
+
 
 def test_NFL():
     nfl = NFL()
